![Instarex](/assets/instarex-thin-banner-transparent.png)

[![Build Status](https://img.shields.io/github/workflow/status/reala10n/insta-rex/Build?style=flat)](ttps://github.com/reala10n/insta-rex/)
[![PyPI version](https://badge.fury.io/py/insta-rex.svg)](https://badge.fury.io/py/insta-rex)
[![Python version](https://img.shields.io/pypi/pyversions/insta-rex)]()

_A friendly and up-to-date [instabot](https://github.com/ohld/igbot) fork for developing Instagram bots to automatically upload posts, stories, IGTV videos and Instagram reels._

## Important

Right now the usage of this library (as probably others too) may harm your Instagram's profile because of new script-detection algorithms. You were warned.
